@@ -2,7 +2,7 @@ import hashlib
 
 from django.contrib.staticfiles.management.commands import collectstatic
 
-from cumulus.storage import CloudFilesStorage
+from cumulus.storage import SwiftclientStorage
 
 class Command(collectstatic.Command):
 
@@ -10,7 +10,7 @@ class Command(collectstatic.Command):
         """
         Checks if the target file should be deleted if it already exists
         """
-        if isinstance(self.storage, CloudFilesStorage):
+        if isinstance(self.storage, SwiftclientStorage):
             if self.storage.exists(prefixed_path):
                 try:
                     etag = self.storage._get_cloud_obj(prefixed_path).etag
